Package: DistributionUtils
Version: 0.6-2
Date: 2025-03-29
Title: Distribution Utilities
Authors@R: person(given = "David",
                  family = "Scott",
                  role = c("aut", "cre"),
                  email = "d.scott@auckland.ac.nz")
Maintainer: David Scott <d.scott@auckland.ac.nz>
Depends: R (>= 3.0.1)
Suggests: GeneralizedHyperbolic, VarianceGamma, SkewHyperbolic, RUnit
Encoding: UTF-8
Description: Utilities are provided which are of use in the
    packages I have developed for dealing with
    distributions. Currently these packages are GeneralizedHyperbolic,
    VarianceGamma, and SkewHyperbolic and NormalLaplace. Each of these
    packages requires DistributionUtils. Functionality includes sample
    skewness and kurtosis, log-histogram, tail plots, moments by
    integration, changing the point about which a moment is
    calculated, functions for testing distributions using inversion
    tests and the Massart inequality. Also includes an implementation
    of the incomplete Bessel K function.
License: GPL (>= 2)
NeedsCompilation: yes
Packaged: 2025-03-29 00:24:59 UTC; dsco0
Author: David Scott [aut, cre]
Repository: CRAN
Date/Publication: 2025-03-29 01:10:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 11:25:19 UTC; unix
Archs: DistributionUtils.so.dSYM
